@@ -1,21 +1,8 @@
 /*
-   This file is part of the KDE games kwin4 program
-   Copyright (c) 2006 Martin Heni <kde@heni-online.de>
+    This file is part of the KDE games kwin4 program
+    SPDX-FileCopyrightText: 2006 Martin Heni <kde@heni-online.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 /** Note: The AI engine of kwin4 does on purpose not implement a perfect 
@@ -25,18 +12,9 @@
   *       see e.g. the Velena AI Engine http://web.archive.org/web/20180219021151/http://www.ce.unipr.it/~gbe/velena.html
   */
 
-// Header includes
 #include "kwin4doc.h"
 
-// include files for Qt
-#include <QDir>
-#include <QStandardPaths>
-#include <QTimer>
-
-// include files for KDE
-#include <KLocalizedString>
-
-// application specific includes
+// own
 #include "kfourinline_debug.h"
 #include "kwin4view.h"
 #include "scoresprite.h"
@@ -44,6 +22,12 @@
 #include "score.h"
 #include "ui_statuswidget.h"
 #include "config-src.h"
+// KF
+#include <KLocalizedString>
+// Qt
+#include <QDir>
+#include <QStandardPaths>
+#include <QTimer>
 
 
 #define FIELD_SIZE_X 7
